AtSyncDialog class

Inheritance

Constructors

AtSyncDialog({required BuildContext context, Color? indicatorColor, Color? backgroundColor, TextStyle? messageStyle, TextStyle? valueStyle})

Properties

backgroundColor ↔ Color?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
indicatorColor ↔ Color?
getter/setter pairinherited
messageStyle ↔ TextStyle?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncStyle → AtSyncStyle
finalinherited
valueStyle ↔ TextStyle?
getter/setter pairinherited

Methods

close() → void
close Closes the progress dialog.
inherited
isOpen() → bool
isOpen Returns whether the dialog box is open.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show({String message = '', bool barrierDismissible = false}) → dynamic
barrierDismissible Determines whether the dialog closes when the back button or screen is clicked. Default: false
inherited
toString() → String
A string representation of this object.
inherited
update({required double? value, String? message}) → void
update Pass the new value to this method to update the status.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited